local addon = Envenomous
if not addon then return end

addon.defaults = {
	profile = {
		dp = {
			enabled = true,
			width = 250,
			height = 16,
			scale = 1, 
			texture = "BantoBar",
			font = "Emblem",
			fontsize = 13,
			position = {},
			showlabel = true,
			showicon = true,
			color = {0.0, 1.0, 0.0, 1.0},
		},
		envenom = {
			enabled = true,
			width = 250,
			height = 16,
			scale = 1,
			texture = "BantoBar",
			font = "Emblem",
			fontsize = 13,
			position = {},
			showlabel = true,
			showicon = true,
			color = {1.0, 1.0, 0.0, 1.0},
		},
	},
}

addon.options = {
	type = "group",
	childGroups = "tab",
	args = {
		tracking = {
			type = "group",
			name = "Options",
			args = {
				trackheader = {
					type = "header",
					name = "Tracking",
					order = 1,
				},
				deadlypoison = {
					type = "toggle",
					name = "Deadly Poison",
					desc = "Track individual poison ticks on enemies.",
					get = function(info) return addon.db.profile.dp.enabled end,
					set = function(info, value)
							addon.db.profile.dp.enabled = value
						end,
					order = 2,
				},
				envenom = {
					type = "toggle",
					name = "Envenom",
					desc = "Track the Envenom buff on yourself.",
					get = function(info) return addon.db.profile.envenom.enabled end,
					set = function(info, value)
							addon.db.profile.envenom.enabled = value
						end,
					order = 3,						
				},
			},
			order = 1
		},
		deadlypoison = {
			type = "group",
			name = "Deadly Poison",
			disabled = function() return not addon.db.profile.dp.enabled end,
			args = {
				header = {
					type = "header",
					name = "Deadly Poison Settings",
					order = 1,
				},
				toggle = {
					type = "execute",
					name = "Toggle anchor",
					desc = "Toggle the bar anchor frame",
					func = function()
							   addon:ToggleAnchor("dp")
						   end,
						  
					order = 2,
				},
				runtest = {
					type = "execute",
					name = "Test",
					desc = "Start a test bar",
					func = function()
							   addon:TestBar("dp")
						   end,
					order = 3,
				},
				bars = {
					type = "group",
					inline = true,
					name = "Bar Settings",
					desc = "Bar Settings",
					args = {
						color = {
							type = "color",
							name = "Color",
							get	= function() return unpack(addon.db.profile.dp.color) end,
							set = function(_, r, g, b, a)
									addon.db.profile.dp.color = {r, g, b, a}
									addon:UpdateAnchor("dp")
								end,
							order = 1,
							hasAlpha = true,
						},
						label = {
							type = "toggle",
							name = "Show Label",
							get = function(info) return addon.db.profile.dp.showlabel end,
							set = function(info, value)
									addon.db.profile.dp.showlabel = value
								end,
							order = 2,
						},
						icon = {
							type = "toggle",
							name = "Show Icon",
							get = function() return addon.db.profile.dp.showicon end,
							set = function(info, value)
									addon.db.profile.dp.showicon = value
									if value then addon.anchor.dp:ShowIcon() else addon.anchor.dp:HideIcon() end
								end,
							order = 3,
						},
						width = {
							type = "range",
							name = "Width",
							desc = "Set the width of the bars",
							get = function() return addon.db.profile.dp.width end,
							set = function(info, v)
									addon.db.profile.dp.width = v
									addon:UpdateAnchor("dp")
								end,
							min = 50,
							max = 500,
							step = 5,
							isPercent = false,
							order = 10,
						},
						height = {
							type = "range",
							name = "Height",
							desc = "Set the height of the bars",
							get = function() return addon.db.profile.dp.height end,
							set = function(info, v)
									addon.db.profile.dp.height = v
									addon:UpdateAnchor("dp")
								end,
							min = 10,
							max = 100,
							step = 1,
							isPercent = false,
							order = 11,
						},
						scale = {
							type = "range",
							name = "Scale",
							desc = "Set the scale of the bars",
							get = function() return addon.db.profile.dp.scale end,
							set = function(info, v)
									addon.db.profile.dp.scale = v
									addon:UpdateAnchor("dp")
								end,
							min = 0.1,
							max = 5,
							step = 0.01,
							isPercent = true,
							order = 12,
						},
						texture = {
							type = "select", dialogControl = 'LSM30_Statusbar',
							name = "Texture",
							desc = "Set the texture for the timer bars",
							values = AceGUIWidgetLSMlists.statusbar,
							get = function(info) return addon.db.profile.dp.texture end,
							set = function(info, value) 
									addon.db.profile.dp.texture = value
									addon:UpdateAnchor("dp")
								end,
							order = 13,
						},
						font = {
							type = "select", dialogControl = 'LSM30_Font',
							name = "Font",
							desc = "Set the bar font",
							values = AceGUIWidgetLSMlists.font,
							get = function(info) return addon.db.profile.dp.font end,
							set = function(info, value)
									addon.db.profile.dp.font = value
									addon:UpdateAnchor("dp")
								end,
							order = 14,
						},
						fontsize = {
							type = "range",
							name = "Font Size",
							desc = "Set the bar font size",
							min = 7,
							max = 48,
							step = 1,
							get = function(info) return addon.db.profile.dp.fontsize end,
							set = function(info, value)
									addon.db.profile.dp.fontsize = value
									addon:UpdateAnchor("dp")
								end,
							order = 15,
						},
					},
					order = 4,
				},
			},
			order = 10,
		},
		envenom = {
			type = "group",
			name = "Envenom",
			disabled = function() return not addon.db.profile.envenom.enabled end,
			args = {
				header = {
					type = "header",
					name = "Envenom Settings",
					order = 1,
				},
				toggle = {
					type = "execute",
					name = "Toggle anchor",
					desc = "Toggle the bar anchor frame",
					func = function()
							   addon:ToggleAnchor("env")
						   end,
						  
					order = 2,
				},
				runtest = {
					type = "execute",
					name = "Test",
					desc = "Start a test bar",
					func = function()
							   addon:TestBar("env")
						   end,
					order = 3,
				},
				bars = {
					type = "group",
					inline = true,
					name = "Bar Settings",
					desc = "Bar Settings",
					args = {
						color = {
							type = "color",
							name = "Color",
							get	= function() return unpack(addon.db.profile.envenom.color) end,
							set = function(_, r, g, b, a)
									addon.db.profile.envenom.color = {r, g, b, a}
									addon:UpdateAnchor("env")
								end,
							order = 1,
							hasAlpha = true,
						},
						label = {
							type = "toggle",
							name = "Show Label",
							get = function(info) return addon.db.profile.envenom.showlabel end,
							set = function(info, value)
									addon.db.profile.envenom.showlabel = value
								end,
							order = 2,
						},
						icon = {
							type = "toggle",
							name = "Show Icon",
							get = function() return addon.db.profile.envenom.showicon end,
							set = function(info, value)
									addon.db.profile.envenom.showicon = value
									if value then addon.anchor.env:ShowIcon() else addon.anchor.env:HideIcon() end
								end,
							order = 3,
						},
						width = {
							type = "range",
							name = "Width",
							desc = "Set the width of the bars",
							get = function() return addon.db.profile.envenom.width end,
							set = function(info, v)
									addon.db.profile.envenom.width = v
									addon:UpdateAnchor("env")
								end,
							min = 50,
							max = 500,
							step = 5,
							isPercent = false,
							order = 10,
						},
						height = {
							type = "range",
							name = "Height",
							desc = "Set the height of the bars",
							get = function() return addon.db.profile.envenom.height end,
							set = function(info, v)
									addon.db.profile.envenom.height = v
									addon:UpdateAnchor("env")
								end,
							min = 10,
							max = 100,
							step = 1,
							isPercent = false,
							order = 11,
						},
						scale = {
							type = "range",
							name = "Scale",
							desc = "Set the scale of the bars",
							get = function() return addon.db.profile.envenom.scale end,
							set = function(info, v)
									addon.db.profile.envenom.scale = v
									addon:UpdateAnchor("env")
								end,
							min = 0.1,
							max = 5,
							step = 0.01,
							isPercent = true,
							order = 12,
						},
						texture = {
							type = "select", dialogControl = 'LSM30_Statusbar',
							name = "Texture",
							desc = "Set the texture for the timer bars",
							values = AceGUIWidgetLSMlists.statusbar,
							get = function(info) return addon.db.profile.envenom.texture end,
							set = function(info, value) 
									addon.db.profile.envenom.texture = value
									addon:UpdateAnchor("env")
								end,
							order = 13,
						},
						font = {
							type = "select", dialogControl = 'LSM30_Font',
							name = "Font",
							desc = "Set the bar font",
							values = AceGUIWidgetLSMlists.font,
							get = function(info) return addon.db.profile.envenom.font end,
							set = function(info, value)
									addon.db.profile.envenom.font = value
									addon:UpdateAnchor("env")
								end,
							order = 14,
						},
						fontsize = {
							type = "range",
							name = "Font Size",
							desc = "Set the bar font size",
							min = 7,
							max = 48,
							step = 1,
							get = function(info) return addon.db.profile.envenom.fontsize end,
							set = function(info, value)
									addon.db.profile.envenom.fontsize = value
									addon:UpdateAnchor("env")
								end,
							order = 15,
						},
					},
					order = 4,
				},
			},
			order = 10,
		},
	},
}

